@@ -156,23 +156,43 @@ get_bys <- function(x, y, by = NULL) {
 
 #' @export
 #' @rdname left_join.
-dt_left_join <- left_join.
+dt_left_join <- function(x, y, by = NULL) {
+  deprecate_soft("0.5.2", "tidytable::dt_left_join()", "left_join.()")
+
+  left_join.(x, y, by)
+}
 
 #' @export
 #' @rdname left_join.
-dt_inner_join <- inner_join.
+dt_inner_join <- function(x, y, by = NULL) {
+  deprecate_soft("0.5.2", "tidytable::dt_inner_join()", "inner_join.()")
+
+  inner_join.(x, y, by)
+}
 
 #' @export
 #' @rdname left_join.
-dt_right_join <- right_join.
+dt_right_join <- function(x, y, by = NULL) {
+  deprecate_soft("0.5.2", "tidytable::dt_right_join()", "right_join.()")
+
+  right_join.(x, y, by)
+}
 
 #' @export
 #' @rdname left_join.
-dt_full_join <- full_join.
+dt_full_join <- function(x, y, by = NULL,suffix =  c(".x", ".y")) {
+  deprecate_soft("0.5.2", "tidytable::dt_full_join()", "full_join.()")
+
+  full_join.(x, y, by)
+}
 
 #' @export
 #' @rdname left_join.
-dt_anti_join <- anti_join.
+dt_anti_join <- function(x, y, by = NULL) {
+  deprecate_soft("0.5.2", "tidytable::dt_anti_join()", "anti_join.()")
+
+  anti_join.(x, y, by)
+}
 
 join_mold <- function(x, y, by = NULL, suffix = c(".x", ".y"), all_x, all_y) {
   if (!is.data.frame(x) | !is.data.frame(y)) stop("x & y must be a data.frame or data.table")
@@ -184,9 +204,6 @@ join_mold <- function(x, y, by = NULL, suffix = c(".x", ".y"), all_x, all_y) {
   by_x <- by_x_y[[1]]
   by_y <- by_x_y[[2]]
 
-  if (by_x %notin% colnames(x)) stop("by.x columns not in x")
-  if (by_y %notin% colnames(y)) stop("by.y columns not in y")
-
   as_tidytable(
     merge(x = x, y = y, by.x = by_x, by.y = by_y, suffixes = suffix,
           all.x = all_x, all.y = all_y,
