@@ -8,5 +8,6 @@
 #' @examples
 #' c(1,3,11) %notin% 1:10
 '%notin%' <- function(x,y){
-  !('%in%'(x,y))
+  # vctrs is faster than base %in%, even inside data.table filter
+  !vec_in(x, y)
 }
