@@ -55,4 +55,8 @@ select..data.frame <- function(.df, ...) {
 
 #' @export
 #' @rdname select.
-dt_select <- select.
+dt_select <- function(.df, ...) {
+  deprecate_soft("0.5.2", "tidytable::dt_select()", "select.()")
+
+  select.(.df, ...)
+}
